#
# spec file for package postgresql
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define defaultpackage postgresql10-openssl_1_0_0

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if 0%{?suse_version} >= 1300
%bcond_without  systemd
%else
%bcond_with     systemd
%endif

Name:           postgresql-openssl_1_0_0
Summary:        Basic Clients and Utilities for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
Version:        10
Release:        lp156.2.1
Url:            https://www.postgresql.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       postgresql-noarch = %version-%release
Provides:       postgresql-noarch = %version-openssl_1_0_0
Requires:       update-alternatives
Recommends:     %defaultpackage
BuildArch:      noarch
Source0:        postgresql-init
Source1:        postgresql-sysconfig
Source2:        postgresql-firewall
Source3:        postgresql-tmpfiles.conf
Source4:        postgresql.service
Source5:        postgresql-bashprofile
Source6:        postgresql-script
Source7:        postgresql-install-alternatives

%if 0%{?suse_version} > 1100
    %define fwdir /etc/sysconfig/SuSEfirewall2.d/services
    %define fwname postgresql
%else
    %define fwdir /etc/sysconfig/scripts
    %define fwname SuSEfirewall2-postgresql
%endif

%description
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the basic utility and client programs necessary
to maintain and work with local or remote PostgreSQL databases as well
as manual pages for the SQL commands that PostgreSQL supports. Full
HTML documentation for PostgreSQL can be found in the postgresql-docs
package.

%package devel
Summary:        PostgreSQL development header files and libraries
Group:          Development/Libraries/C and C++
Provides:       postgresql-devel-noarch = %version-%release
Provides:       pkgconfig(libecpg) = %{version}-%{release}
Provides:       pkgconfig(libecpg_compat) = %{version}-%{release}
Provides:       pkgconfig(libpgtypes) = %{version}-%{release}
Provides:       pkgconfig(libpq) = %{version}-%{release}
Requires:       postgresql-devel-implementation
Recommends:     %defaultpackage-devel

%description devel
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the header files and libraries needed to compile
C applications which will directly interact with a PostgreSQL database
management server and the ECPG Embedded C Postgres preprocessor. You
need to install this package if you want to develop applications in C
which will interact with a PostgreSQL server.

%prep

%build
echo "This is a dummy package to provide a dependency on the default PostgreSQL version." > README

%install
install -m755 -d %buildroot/usr/sbin

install -m755 -d %buildroot/usr/share/postgresql
install -m755 %{S:7} %buildroot/usr/share/postgresql/install-alternatives

%define eflag /run/postgresql-was-enabled
%define aflag /run/postgresql-was-running

%files
%defattr(-,root,root,-)
%doc README
%dir /usr/share/postgresql
/usr/share/postgresql/install-alternatives

%files devel
%defattr(-,root,root,-)
%doc README

%changelog
* Mon Apr 30 2018 dimstar@opensuse.org
- Require update-alternatives by postgresql: one of the main
  scripts in use is install-alternatives, which calls u-a.
* Fri Feb  2 2018 max@suse.com
- Put POSTGRES_LANG into LC_ALL instead of LANG to retain the
  previous behaviour of that variable (boo#1077027).
* Wed Jan 17 2018 max@suse.com
- postgresql-script: /etc/sysconfig/language is deprecated, use the
  locale that was inherited from systemd instead for initializing
  a new database instance (boo#1074988).
* Wed Dec 13 2017 mrueckert@suse.de
- add provides for all the pkgconfig() provides you also find in
  the postgresqlXY-devel packages. then we automatically will pull
  postgresql-devel which in turn will pull our default
  postgresqlXY-devel package. (boo#1071971)
* Wed Dec  6 2017 bruno@ioda-net.ch
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 24 2017 mrueckert@suse.de
- instead of hardcoding version 10, just check if the prio is
  smaller than 80.
* Thu Nov 23 2017 mrueckert@suse.de
- simplify the postgresql-install-alternatives to only require the
  pg version and go from there.
  supported calls of the script are:
  /usr/share/postgresql/install-alternatives postgresqlXY
  /usr/share/postgresql/install-alternatives XY
  where XY can currently be: 92 93 94 95 96 10
* Wed Nov 22 2017 max@suse.com
- CVE-2017-14798, bsc#1062722: Fix LPE via postgres init script.
  This only affected SysV-init based systems (i.e. SLE11).
* Tue Nov 14 2017 max@suse.com
- postgresql-test was missing a %%files section.
* Fri Nov  3 2017 max@suse.com
- Move the start/stop script to /usr/share/postgresql
- Add a script for handling update-alternatives as subpackages
  get installed/uninstalled, so that the implementation packages
  don't have to repeat the logic (postgresql-install-alternatives).
- Add the postgresql-test subpackage.
- Fix some dependencies.
- Save the enabled and running state when upgrading from the
  obsolete postgresql-init package.
* Fri Oct  6 2017 mrueckert@suse.de
- properly guard the systemd macro in %%pre server so it wont be
  used on sle11
- add Requires(pre) so we have groupadd/useradd available
* Thu Sep 21 2017 max@suse.com
- Refine the dependencies between the "dummy" packages and the
  actual implementation of PostgreSQL. The dummy packages now
  require an arbitrary implementation and recommend the default
  version.
- Move the contents of postgresql-init to the server package.
* Thu Aug  3 2017 mrueckert@suse.de
- bump to 10
* Wed Jun 28 2017 max@suse.com
- Bump version and defaultpackage to 9.6 in SLE12 (bsc#1046324).
* Sun Oct 30 2016 13ilya@gmail.com
- Bump version and defaultpackage to 9.6 in Factory.
* Mon Sep 28 2015 max@suse.com
- Move ~postgres/.bash_profile to postgresql-server to avoid a
  file conflict between the versioned server packages.
* Sun Aug 16 2015 ro@suse.de
- Bump version and defaultpackage to 9.4. in SLE (bnc#941886)
* Wed Feb 18 2015 max@suse.com
- Bump version and defaultpackage to 9.4 in Factory.
* Tue Sep 17 2013 max@suse.com
- Bump version and defaultpackage to 9.3.
* Wed Jan  9 2013 max@suse.com
- Change license string to PostgreSQL.
* Fri Oct  5 2012 max@suse.com
- Make all dummy packages noarch.
* Thu Oct  4 2012 max@suse.com
- Make PostgreSQL 9.2 the default.
* Mon Oct  1 2012 max@suse.com
- Reduce the postgresql packages with unversioned names to dummy
  packages that require the respective versioned package names.
